@@ -311,19 +311,20 @@ class LocalNodeManager:
         # if they are set to empty values
         if not await asyncstdlib.all(
             (
-                data["lavalink"]["server"]["youtubeConfig"]["email"],
-                data["lavalink"]["server"]["youtubeConfig"]["password"],
+                data["lavalink"]["server"]["youtubeConfig"].get("email"),
+                data["lavalink"]["server"]["youtubeConfig"].get("password"),
             )
         ):
             del data["lavalink"]["server"]["youtubeConfig"]
-        if not data["lavalink"]["server"]["ratelimit"]["ipBlocks"]:
+        if not (
+            data["lavalink"]["server"]["ratelimit"].get("ipBlocks")
+            and data["lavalink"]["server"]["ratelimit"].get("strategy")
+        ):
             del data["lavalink"]["server"]["ratelimit"]
         if data["sentry"]["dsn"]:
             data["sentry"]["tags"]["ID"] = self._client.bot.user.id
             data["sentry"]["tags"]["pylav_version"] = self._client.lib_version
-        if not data["lavalink"]["server"]["httpConfig"] or not data["lavalink"]["server"]["httpConfig"].get(
-            "proxyHost"
-        ):
+        if not data["lavalink"]["server"]["httpConfig"].get("proxyHost"):
             del data["lavalink"]["server"]["httpConfig"]
         self._current_config = data
         async with LAVALINK_APP_YML.open("w") as f:
