@@ -41,7 +41,8 @@ class LibConfigRow(Table, db=DB, tablename="lib_config"):
     localtrack_folder = Text(null=True)
     java_path = Text(null=False, default="java")
     enable_managed_node = Boolean(null=False, default=True)
-    use_bundled_external = Boolean(null=False, default=True)
+    use_bundled_lava_link_external = Boolean(null=False, default=True)
+    use_bundled_pylav_external = Boolean(null=False, default=True)
     auto_update_managed_nodes = Boolean(null=False, default=True)
     download_id = BigInt(index=True, default=0)
     extras: JSONB = JSONB(null=False, default={})
