@@ -10,7 +10,7 @@ import random
 import threading
 import time
 from asyncio import QueueFull, events, locks
-from collections.abc import AsyncIterable, AsyncIterator, Awaitable, Generator, Iterable, Iterator
+from collections.abc import AsyncIterable, AsyncIterator, Awaitable, Coroutine, Generator, Iterable, Iterator
 from copy import copy
 from enum import Enum
 from itertools import chain
@@ -38,6 +38,7 @@ from discord.ext.commands import Context as DpyContext
 
 if TYPE_CHECKING:
     from pylav import Player
+    from pylav.node import Node
 
 __all__ = (
     "MISSING",
@@ -849,6 +850,10 @@ async def dummy_command(self, context: PyLavContext):
     """Does nothing."""
 
 
+async def sort_key_nodes(node: Node, region: str = None) -> float:
+    return await node.penalty_with_region(region)
+
+
 # Everything under here is taken from
 #   https://github.com/Cog-Creators/Red-DiscordBot/blob/V3/develop/redbot/core/utils/__init__.py
 #   and is licensed under the GPLv3 license (https://github.com/Cog-Creators/Red-DiscordBot/blob/V3/develop/LICENSE
